# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-09-21 07:52
from __future__ import unicode_literals

import datetime
from django.db import migrations, models
from django.utils.timezone import utc


class Migration(migrations.Migration):

    dependencies = [
        ('editorial_staff', '0004_auto_20170921_0032'),
    ]

    operations = [
        migrations.AddField(
            model_name='staffer',
            name='created',
            field=models.DateTimeField(auto_now_add=True, default=datetime.datetime(2017, 7, 1, 7, 0, tzinfo=utc)),
            preserve_default=False,
        ),
    ]
