@import url(https://fonts.googleapis.com/css?family=IM+Fell+DW+Pica|Raleway:300,400|Open+Sans+Condensed:300);


html, body, div, span, applet, object, iframe,
h1, h2, h3, h4, h5, h6, p, blockquote, pre,
a, abbr, acronym, address, big, cite, code,
del, dfn, em, img, ins, kbd, q, s, samp,
small, strike, strong, sub, sup, tt, var,
b, u, i, center,
dl, dt, dd, ol, ul, li,
fieldset, form, label, legend,
table, caption, tbody, tfoot, thead, tr, th, td,
article, aside, canvas, details, embed,
figure, figcaption, footer, header, hgroup,
menu, nav, output, ruby, section, summary,
time, mark, audio, video {
	margin: 0;
	padding: 0;
	border: 0;
	font-size: 100%;
	font: inherit;
	vertical-align: baseline;
}
/* HTML5 display-role reset for older browsers */
article, aside, details, figcaption, figure,
footer, header, hgroup, menu, nav, section {
	display: block;
}
body {
	line-height: 1;
}
ol, ul {
	list-style: none;
}
blockquote, q {
	quotes: none;
}
blockquote:before, blockquote:after,
q:before, q:after {
	content: '';
	content: none;
}
table {
	border-collapse: collapse;
	border-spacing: 0;
}
a:hover, a:focus{
	text-decoration: none !important;
}

#stickyNav{
	background-color: #3D5B43;
	z-index: 9999999999999999;
	font-family: 'IM Fell DW Pica';
	font-size: 40px;
	color:white;
	padding:8px 20px 0px;
	position:fixed;
	top: 0;
	left: 0;
	width:100%;

}
#stickyNav img{
	height:15px;
	padding:0px;
	float:left;

}
#stickyNav a,#stickyNav a:hover{
	color:white;
	text-decoration: none;
}

body{
	padding-top:65px;
}
.content{
	padding:10px 20px;
}

.breadcrumb{
	position: fixed;
    top: 65px;
    left: 0px;
}


.blink{
  animation: blinker 1s cubic-bezier(0, 0, 0,1) infinite alternate;
}
@keyframes blinker {
  from { opacity: 0; }
  to { opacity: 1; }
}

.fa-spin {
    -webkit-animation: fa-spin 3s infinite linear;
    animation: fa-spin 3s infinite linear;
}
