//

export default class RippleAdapter {
  /* eslint-disable class-methods-use-this,no-unused-vars */
  browserSupportsCssVars() {}

  isUnbounded() {}

  isSurfaceActive() {}

  isSurfaceDisabled() {}

  addClass(className) {}

  removeClass(className) {}

  registerInteractionHandler(evtType, handler) {}

  deregisterInteractionHandler(evtType, handler) {}

  registerResizeHandler(handler) {}

  deregisterResizeHandler(handler) {}

  updateCssVariable(varName, value) {}

  computeBoundingRect() {}

  getWindowPageOffset() {}
  /* eslint-enable class-methods-use-this */
}
