/*           */
/* Variables */
/*           */

// $primary-color: #446178;
$primary-color: #00695C;  // 800

// $primary-button-color: #446178;
$primary-button-color: #00796B;  // 700

// $form-focus-color: #337AB7;
$form-focus-color: #00897B;  // 600
$form-error-color: #D9534F !default;
$form-transition-speed: 0.28s !default;


$snackbar-secondary-color: #80CBC4 !default;  // 200

$base-lr-gutter: 24px;


@mixin undo-bs-tab-focus() {
  // clear out the tab-focus() from BS
  &,
  &:active,
  &.active {
    &:focus,
    &.focus {
      //@include tab-focus();
      outline: 0;
    }
  }
}
