//

export const cssClasses = {
  ROOT: 'snackbar',
  TEXT: 'snackbar-text',
  ACTION_WRAPPER: 'snackbar-action-wrapper',
  ACTION_BUTTON: 'snackbar-action-button',
  ACTIVE: 'snackbar-active',
  MULTILINE: 'snackbar-multiline',
  ACTION_ON_BOTTOM: 'snackbar-action-on-bottom',
};

export const strings = {
  TEXT_SELECTOR: '.snackbar-text',
  ACTION_WRAPPER_SELECTOR: '.snackbar-action-wrapper',
  ACTION_BUTTON_SELECTOR: '.snackbar-action-button',
};

export const numbers = {
  MESSAGE_TIMEOUT: 2750,
};
