# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-09-21 07:32
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('editorial_staff', '0003_auto_20170821_1239'),
    ]

    operations = [
        migrations.AlterField(
            model_name='staffer',
            name='image_url',
            field=models.URLField(blank=True, help_text='Usually auto-populated from Slack.', null=True),
        ),
    ]
